do_resample_frames

Function do_resample_frames 

pub fn do_resample_frames<S>(
    resampler: &Resampler,
    input: &[Vec<S>],
    src_sample_rate: u32,
    dst_sample_rate: u32,
) -> Vec<Vec<S>>
where S: SampleType,
  • Use the Resampler to resample audio frames from the original sample rate to a specific sample rate.